@@ -30,6 +30,7 @@ use tui::Terminal;
 
 mod colors;
 mod plot_data;
+mod region_map;
 
 use colors::Colors;
 use shadow_rs::{formatcp, shadow};
@@ -63,8 +64,7 @@ struct Args {
     )]
     watch_interval: Option<f32>,
     #[structopt(
-        help = "Hosts or IPs to ping, or commands to run if --cmd is provided.",
-        required = true
+        help = "Hosts or IPs to ping, or commands to run if --cmd is provided. Can use cloud shorthands like aws:eu-west-1."
     )]
     hosts_or_commands: Vec<String>,
     #[structopt(
@@ -171,11 +171,11 @@ impl App {
         let upper = Local::from_utc_datetime(&Local, &upper_utc);
         let diff = (upper - lower) / 2;
         let midpoint = lower + diff;
-        return vec![
+        vec![
             Span::raw(format!("{:?}", lower.time())),
             Span::raw(format!("{:?}", midpoint.time())),
             Span::raw(format!("{:?}", upper.time())),
-        ];
+        ]
     }
 
     fn y_axis_labels(&self, bounds: [f64; 2]) -> Vec<Span> {
@@ -266,16 +266,16 @@ fn start_ping_thread(
     watch_interval: Option<f32>,
     ping_tx: Sender<Event>,
     kill_event: Arc<AtomicBool>,
-) -> JoinHandle<Result<()>> {
+) -> Result<JoinHandle<Result<()>>> {
     let interval = Duration::from_millis((watch_interval.unwrap_or(0.2) * 1000.0) as u64);
     // Pump ping messages into the queue
-    thread::spawn(move || -> Result<()> {
-        let stream = ping_with_interval(host, interval)?;
+    let stream = ping_with_interval(host, interval)?;
+    Ok(thread::spawn(move || -> Result<()> {
         while !kill_event.load(Ordering::Acquire) {
             ping_tx.send(Event::Update(host_id, stream.recv()?.into()))?;
         }
         Ok(())
-    })
+    }))
 }
 
 fn get_host_ipaddr(host: &str, force_ipv4: bool, force_ipv6: bool) -> Result<String> {
@@ -307,7 +307,17 @@ fn main() -> Result<()> {
     let mut data = vec![];
 
     let colors = Colors::from(args.color_codes_or_names.iter());
-    for (host_or_cmd, color) in args.hosts_or_commands.iter().zip(colors) {
+    let hosts_or_commands: Vec<String> = args
+        .hosts_or_commands
+        .clone()
+        .into_iter()
+        .map(|s| match region_map::try_host_from_cloud_region(&s) {
+            None => s,
+            Some(new_domain) => new_domain,
+        })
+        .collect();
+
+    for (host_or_cmd, color) in hosts_or_commands.iter().zip(colors) {
         let color = color?;
         let display = match args.cmd {
             true => host_or_cmd.to_string(),
@@ -325,23 +335,13 @@ fn main() -> Result<()> {
         ));
     }
 
-    let mut app = App::new(data, args.buffer);
-    enable_raw_mode()?;
-    let mut stdout = io::stdout();
-    execute!(stdout, EnterAlternateScreen, EnableMouseCapture)?;
-    let backend = CrosstermBackend::new(stdout);
-
-    let mut terminal = Terminal::new(backend)?;
-
-    terminal.clear()?;
-
     let (key_tx, rx) = mpsc::channel();
 
     let mut threads = vec![];
 
     let killed = std::sync::Arc::new(std::sync::atomic::AtomicBool::new(false));
 
-    for (host_id, host_or_cmd) in args.hosts_or_commands.iter().cloned().enumerate() {
+    for (host_id, host_or_cmd) in hosts_or_commands.iter().cloned().enumerate() {
         if args.cmd {
             let cmd_thread = start_cmd_thread(
                 &host_or_cmd,
@@ -358,10 +358,18 @@ fn main() -> Result<()> {
                 args.watch_interval,
                 key_tx.clone(),
                 std::sync::Arc::clone(&killed),
-            ));
+            )?);
         }
     }
 
+    let mut app = App::new(data, args.buffer);
+    enable_raw_mode()?;
+    let mut stdout = io::stdout();
+    execute!(stdout, EnterAlternateScreen, EnableMouseCapture)?;
+    let backend = CrosstermBackend::new(stdout);
+    let mut terminal = Terminal::new(backend)?;
+    terminal.clear()?;
+
     // Pump keyboard messages into the queue
     let killed_thread = std::sync::Arc::clone(&killed);
     let key_thread = thread::spawn(move || -> Result<()> {
